@@ -3,6 +3,9 @@ library(biorxivr)
 bxEco <- bx_search("Ecology",limit = 10)
 summary(bxEco)
 
+## ----hidden,echo=F-------------------------------------------------------
+bxEco <- bx_search("Gotelli and Hart",limit = 10)
+
 ## ----get details---------------------------------------------------------
 bxEcoDetails <-  bx_extract(bxEco)
 
